@@ -43,6 +43,10 @@ def new_version(package, name, script_type='sql', vcs='git', schema_diff=None, e
     elif script_type == 'py':
         migration_fn = '%s_%s.py' % (version, name)
 
+    schema_diff_result = ''
+    if (upgrade_fn or downgrade_fn) and schema_diff:
+        schema_diff_result = os.popen(schema_diff).read()
+
     artefacts = []
     # Create upgrade / downgrade scripts.
     if migration_fn:
@@ -53,16 +57,12 @@ def new_version(package, name, script_type='sql', vcs='git', schema_diff=None, e
 
     if upgrade_fn:
         upgrade_fn = resource_filename(package, upgrade_fn)
-        file(upgrade_fn, 'w').write(UPGRADE_FILE_TEMPLATE)
-        if schema_diff is not None:
-            os.system('%s >> %s' % (schema_diff, upgrade_fn))
+        file(upgrade_fn, 'w').write(UPGRADE_FILE_TEMPLATE + schema_diff_result)
         artefacts.append(upgrade_fn)
 
     if downgrade_fn:
         downgrade_fn = resource_filename(package, downgrade_fn)
-        file(downgrade_fn, 'w').write(DOWNGRADE_FILE_TEMPLATE)
-        if schema_diff is not None:
-            os.system('%s >> %s' % (schema_diff, downgrade_fn))
+        file(downgrade_fn, 'w').write(DOWNGRADE_FILE_TEMPLATE + schema_diff_result)
         artefacts.append(downgrade_fn)
 
     os.system('%s %s' % (editor, ' '.join(artefacts)))
